from . import cythoncompile

__author__ = 'Minh Tuan Nguyen'
__version__ = '0.1.2'
__copyright__ = "Copyright 2018, Minh Tuan Nguyen"
__credits__ = ["Minh Tuan Nguyen", ]
__license__ = "MIT"

# python setup.py bdist_wheel
# python setup.py sdist bdist_wheel
# twine upload dist/*
